@@ -1,3 +1,4 @@
+#[doc(hidden)]
 #[macro_export]
 /// internal macro to extend the dataframe to standardize the structure for MPI protocol
 ///
@@ -40,27 +41,19 @@ macro_rules! extend_dataframe_explore {
     };
 }
 
-/// macro to perform distribued model exploration using a genetic algorithm based on MPI
+/// Macro to perform distribued model exploration using a genetic algorithm based on MPI
 ///
-/// init_population: function that creates the population, must return an array of individual. An individual is the state of the simulation to compute
-///
-/// fitness: function that computes the fitness value, takes a single individual and the schedule, must return an f32
-///
-/// selection: function that select pair of individuals with some criterion and create a new individual for the next generation
-///
-/// mutation: function that perform the mutation, takes a single individual as parameter
-///
-/// crossover: function that creates the population, takes the entire population as parameter
-///
-/// state: state of the simulation representing an individual
-///
-/// desired_fitness: desired fitness value
-///
-/// generation_num: max number of generations to compute
-///
-/// step: number of steps of the single simulation
-///
-/// reps: optional values for number of repetitions
+/// # Arguments
+/// *init_population` - function that creates the population, must return an array of individual. An individual is the state of the simulation to compute
+/// *fitness` - function that computes the fitness value, takes a single individual and the schedule, must return an f32
+/// *selection` - function that select pair of individuals with some criterion and create a new individual for the next generation
+/// *mutation` - function that perform the mutation, takes a single individual as parameter
+/// *crossover` - function that creates the population, takes the entire population as parameter
+/// *state` - state of the simulation representing an individual
+/// *desired_fitness` - desired fitness value
+/// *generation_num` - max number of generations to compute
+/// *step` - number of steps of the single simulation
+/// *reps` - optional values for number of repetitions
 #[macro_export]
 macro_rules! explore_ga_distributed_mpi {
     (
