@@ -1,8 +1,4 @@
-
 #[cfg(test)]
-
-
-
 #[cfg(not(any(
     feature = "visualization",
     feature = "visualization_wasm",
@@ -15,8 +11,8 @@ fn schedule_operations() {
     use crate::utils::mynode::MyNode;
 
     let mut schedule = Schedule::new();
-    let node1 = MyNode{ id: 0, flag: false };
-    let node2 = MyNode{ id: 1, flag: false };
+    let node1 = MyNode { id: 0, flag: false };
+    let node2 = MyNode { id: 1, flag: false };
 
     schedule.schedule_repeating(Box::new(node1), 0., 0);
     schedule.schedule_repeating(Box::new(node2), 0., 0);
@@ -24,8 +20,11 @@ fn schedule_operations() {
     let agents = schedule.get_all_events();
     assert_eq!(agents.len(), 2);
 
-    for (i,a) in agents.iter().enumerate() {
-        assert_eq!(*a.downcast_ref::<MyNode>().unwrap(), if i == 0 { node1 } else { node2 });
+    for (i, a) in agents.iter().enumerate() {
+        assert_eq!(
+            *a.downcast_ref::<MyNode>().unwrap(),
+            if i == 0 { node1 } else { node2 }
+        );
     }
 
     assert!(schedule.dequeue(Box::new(node1), node1.id));
@@ -37,7 +36,4 @@ fn schedule_operations() {
     assert!(schedule.dequeue(Box::new(node2), node2.id));
     let agents = schedule.get_all_events();
     assert_eq!(agents.len(), 0);
-    
-    
-
 }
